@@ -30,6 +30,13 @@ value <- obj[["a"]]
 str(value)
 stopifnot(identical(value, 1:100))
 
+obj[["a"]] <- 1:101
+print(obj)
+
+value <- obj[["a"]]
+str(value)
+stopifnot(identical(value, 1:101))
+
 size <- objectSize(obj)
 print(size)
 
@@ -49,9 +56,35 @@ print(res)
 stopifnot(exists("a", mode="integer"))
 str(a)
 
+## Object already attached
+res <- tryCatch(attach(obj), warning=function(w) w)
+stopifnot(inherits(res, "warning"))
+
 res <- detach(obj)
 print(res)
 
+## Object already detached
+res <- tryCatch(detach(obj), warning=function(w) w)
+stopifnot(inherits(res, "warning"))
+
+
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# Save and load
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+obj <- Object()
+obj$a <- 1
+obj$b <- 2
+pathnameT <- tempfile()
+save(obj, file=pathnameT)
+
+obj2 <- Object$load(pathnameT)
+stopifnot(all.equal(getFields(obj2), getFields(obj)))
+for (key in getFields(obj)) {
+  stopifnot(identical(obj2[[key]], obj[[key]]))
+}
+
+file.remove(pathnameT)
+
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Class
